SmartWallet class

Implementers

Constructors

SmartWallet({required String abi, required String scwAddress, dynamic provider, required EntryPointWithoutSigner entryPointContract, required bool isInitialized, required String entryPointAddress, required String ownerAddress, required int salt, required String bundlerURL, required String rpcURL, dynamic usePaymaster, dynamic batch, PaymasterConfig? paymasterConfig})

Properties

abi String
getter/setter pair
batch Map<int, dynamic>
getter/setter pair
bundlerURL String
getter/setter pair
defaultPaymaster Paymaster?
getter/setter pair
deployedContract ↔ DeployedContract
getter/setter pair
entryPointAddress String
getter/setter pair
entryPointContract EntryPointWithoutSigner
getter/setter pair
factoryAddress String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
initCode String
getter/setter pair
isInitialized bool
getter/setter pair
isVerified bool
getter/setter pair
ownerAddress String
getter/setter pair
paymasterConfig PaymasterConfig
getter/setter pair
rpcURL String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
salt int
getter/setter pair
scwAddress String
getter/setter pair
usePaymaster bool
getter/setter pair
web3Client ↔ Web3Client
getter/setter pair

Methods

addContractCallToBatch({required String contractAddress, required String contractAbi, required String functionName, required List args, BigInt? gasPrice, BigInt? gasLimit}) Future<bool>
attachPaymaster(Paymaster paymaster) bool
callContract({required String contractAddress, required String contractAbi, required String functionName, required List args, bool? useDefaultPaymaster, required String currentAddress, BigInt? gasPrice, BigInt? gasLimit}) Future<RPCResult>
callContractDirect({required String contractAddress, required String contractAbi, required String functionName, required List args, required String currentAddress, bool? useDefaultPaymaster, BigInt? gasPrice, BigInt? gasLimit}) Future<String?>
clearBatch() bool
concatenateBuffers(List<Uint8List> buffers) Uint8List
constructPaymasterAndData(String paymasterAddress, String validTimeRangeHex, String signedPayMasterData) Uint8List
detachPaymaster() bool
encodeParameters(List<String> types, List values) String
executeBatch(String currentAddress, bool? useDefaultPaymaster) Future<String?>
fetchPersonalSignature(String message, String currentAddress) Future<String>
getEncodedDataAsList({required String contractAddress, required String contractAbi, required String functionName, required List args, BigInt? gasPrice, BigInt? gasLimit}) Future<List>
getExecuteBatchEncodedData() String
getNonce() Future<BigInt>
getUserOpEncodedDataAsString({required String contractAddress, required String contractAbi, required String functionName, required List args, BigInt? gasPrice, BigInt? gasLimit}) Future<String>
getUserOpTransactionHash(String? userOpHash) Future<String?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeFromBatch(int id) Future<bool>
sendSignedOp(String signature, UserOperation userOp, bool useDefaultPaymaster) Future<String?>
sendTransaction(String currentAddress) Future<String>
submitUseropToOctacore(String signature, UserOperation userOp, bool useDefaultPaymaster, int? validUntil, int? validAfter) Future<Response?>
toString() String
A string representation of this object.
inherited
transfer(String toAddress, String value, String data, bool usePaymaster, String currentAddress) Future<RPCResult>

Operators

operator ==(Object other) bool
The equality operator.
inherited